@@ -65,10 +65,11 @@ func TestDeprecationLogLevelFromVersion(t *testing.T) {
 }
 
 type testConfig struct {
-	environment string
-	running     bool
-	workingDir  string
-	multihost   bool
+	environment  string
+	running      bool
+	workingDir   string
+	multihost    bool
+	multilingual bool
 }
 
 func (c testConfig) Environment() string {
@@ -86,3 +87,7 @@ func (c testConfig) WorkingDir() string {
 func (c testConfig) IsMultihost() bool {
 	return c.multihost
 }
+
+func (c testConfig) IsMultilingual() bool {
+	return c.multilingual
+}
