@@ -16,13 +16,13 @@ package config
 import (
 	"encoding/json"
 
-	"github.com/gohugoio/hugo/identity"
+	"github.com/gohugoio/hugo/common/hashing"
 )
 
 func DecodeNamespace[S, C any](configSource any, buildConfig func(any) (C, any, error)) (*ConfigNamespace[S, C], error) {
 	// Calculate the hash of the input (not including any defaults applied later).
 	// This allows us to introduce new config options without breaking the hash.
-	h := identity.HashString(configSource)
+	h := hashing.HashString(configSource)
 
 	// Build the config
 	c, ext, err := buildConfig(configSource)
