@@ -31,6 +31,8 @@ import (
 	"testing"
 
 	"github.com/gohugoio/hugo/common/loggers"
+	"github.com/gohugoio/hugo/deploy/deployconfig"
+	"github.com/gohugoio/hugo/hugofs"
 	"github.com/gohugoio/hugo/media"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
@@ -109,7 +111,7 @@ func TestFindDiffs(t *testing.T) {
 		{
 			Description: "local == remote with route.Force true -> diffs",
 			Local: []*localFile{
-				{NativePath: "aaa", SlashPath: "aaa", UploadSize: 1, matcher: &Matcher{Force: true}, md5: hash1},
+				{NativePath: "aaa", SlashPath: "aaa", UploadSize: 1, matcher: &deployconfig.Matcher{Force: true}, md5: hash1},
 				makeLocal("bbb", 2, hash1),
 			},
 			Remote: []*blob.ListObject{
@@ -214,8 +216,9 @@ func TestFindDiffs(t *testing.T) {
 
 func TestWalkLocal(t *testing.T) {
 	tests := map[string]struct {
-		Given  []string
-		Expect []string
+		Given   []string
+		Expect  []string
+		MapPath func(string) string
 	}{
 		"Empty": {
 			Given:  []string{},
@@ -233,6 +236,11 @@ func TestWalkLocal(t *testing.T) {
 			Given:  []string{"file.txt", ".hidden_dir/file.txt", ".well-known/file.txt"},
 			Expect: []string{"file.txt", ".well-known/file.txt"},
 		},
+		"StripIndexHTML": {
+			Given:   []string{"index.html", "file.txt", "dir/index.html", "dir/file.txt"},
+			Expect:  []string{"index.html", "file.txt", "dir/", "dir/file.txt"},
+			MapPath: stripIndexHTML,
+		},
 	}
 
 	for desc, tc := range tests {
@@ -241,7 +249,7 @@ func TestWalkLocal(t *testing.T) {
 			for _, name := range tc.Given {
 				dir, _ := path.Split(name)
 				if dir != "" {
-					if err := fs.MkdirAll(dir, 0755); err != nil {
+					if err := fs.MkdirAll(dir, 0o755); err != nil {
 						t.Fatal(err)
 					}
 				}
@@ -252,7 +260,7 @@ func TestWalkLocal(t *testing.T) {
 				}
 			}
 			d := newDeployer()
-			if got, err := d.walkLocal(fs, nil, nil, nil, media.DefaultTypes); err != nil {
+			if got, err := d.walkLocal(fs, nil, nil, nil, media.DefaultTypes, tc.MapPath); err != nil {
 				t.Fatal(err)
 			} else {
 				expect := map[string]any{}
@@ -272,6 +280,63 @@ func TestWalkLocal(t *testing.T) {
 	}
 }
 
+func TestStripIndexHTML(t *testing.T) {
+	tests := map[string]struct {
+		Input  string
+		Output string
+	}{
+		"Unmapped": {Input: "normal_file.txt", Output: "normal_file.txt"},
+		"Stripped": {Input: "directory/index.html", Output: "directory/"},
+		"NoSlash":  {Input: "prefix_index.html", Output: "prefix_index.html"},
+		"Root":     {Input: "index.html", Output: "index.html"},
+	}
+	for desc, tc := range tests {
+		t.Run(desc, func(t *testing.T) {
+			got := stripIndexHTML(tc.Input)
+			if got != tc.Output {
+				t.Errorf("got %q, expect %q", got, tc.Output)
+			}
+		})
+	}
+}
+
+func TestStripIndexHTMLMatcher(t *testing.T) {
+	// StripIndexHTML should not affect matchers.
+	fs := afero.NewMemMapFs()
+	if err := fs.Mkdir("dir", 0o755); err != nil {
+		t.Fatal(err)
+	}
+	for _, name := range []string{"index.html", "dir/index.html", "file.txt"} {
+		if fd, err := fs.Create(name); err != nil {
+			t.Fatal(err)
+		} else {
+			fd.Close()
+		}
+	}
+	d := newDeployer()
+	const pattern = `\.html$`
+	matcher := &deployconfig.Matcher{Pattern: pattern, Gzip: true, Re: regexp.MustCompile(pattern)}
+	if got, err := d.walkLocal(fs, []*deployconfig.Matcher{matcher}, nil, nil, media.DefaultTypes, stripIndexHTML); err != nil {
+		t.Fatal(err)
+	} else {
+		for _, name := range []string{"index.html", "dir/"} {
+			lf := got[name]
+			if lf == nil {
+				t.Errorf("missing file %q", name)
+			} else if lf.matcher == nil {
+				t.Errorf("file %q has nil matcher, expect %q", name, pattern)
+			}
+		}
+		const name = "file.txt"
+		lf := got[name]
+		if lf == nil {
+			t.Errorf("missing file %q", name)
+		} else if lf.matcher != nil {
+			t.Errorf("file %q has matcher %q, expect nil", name, lf.matcher.Pattern)
+		}
+	}
+}
+
 func TestLocalFile(t *testing.T) {
 	const (
 		content = "hello world!"
@@ -292,7 +357,7 @@ func TestLocalFile(t *testing.T) {
 	tests := []struct {
 		Description         string
 		Path                string
-		Matcher             *Matcher
+		Matcher             *deployconfig.Matcher
 		MediaTypesConfig    map[string]any
 		WantContent         []byte
 		WantSize            int64
@@ -318,7 +383,7 @@ func TestLocalFile(t *testing.T) {
 		{
 			Description:      "CacheControl from matcher",
 			Path:             "foo.txt",
-			Matcher:          &Matcher{CacheControl: "max-age=630720000"},
+			Matcher:          &deployconfig.Matcher{CacheControl: "max-age=630720000"},
 			WantContent:      contentBytes,
 			WantSize:         contentLen,
 			WantMD5:          contentMD5[:],
@@ -327,7 +392,7 @@ func TestLocalFile(t *testing.T) {
 		{
 			Description:         "ContentEncoding from matcher",
 			Path:                "foo.txt",
-			Matcher:             &Matcher{ContentEncoding: "foobar"},
+			Matcher:             &deployconfig.Matcher{ContentEncoding: "foobar"},
 			WantContent:         contentBytes,
 			WantSize:            contentLen,
 			WantMD5:             contentMD5[:],
@@ -336,7 +401,7 @@ func TestLocalFile(t *testing.T) {
 		{
 			Description:     "ContentType from matcher",
 			Path:            "foo.txt",
-			Matcher:         &Matcher{ContentType: "foo/bar"},
+			Matcher:         &deployconfig.Matcher{ContentType: "foo/bar"},
 			WantContent:     contentBytes,
 			WantSize:        contentLen,
 			WantMD5:         contentMD5[:],
@@ -345,7 +410,7 @@ func TestLocalFile(t *testing.T) {
 		{
 			Description:         "gzipped content",
 			Path:                "foo.txt",
-			Matcher:             &Matcher{Gzip: true},
+			Matcher:             &deployconfig.Matcher{Gzip: true},
 			WantContent:         gzBytes,
 			WantSize:            gzLen,
 			WantMD5:             gzMD5[:],
@@ -530,7 +595,7 @@ func initFsTests(t *testing.T) []*fsTest {
 	membucket := memblob.OpenBucket(nil)
 	t.Cleanup(func() { membucket.Close() })
 
-	filefs := afero.NewBasePathFs(afero.NewOsFs(), tmpfsdir)
+	filefs := hugofs.NewBasePathFs(afero.NewOsFs(), tmpfsdir)
 	filebucket, err := fileblob.OpenBucket(tmpbucketdir, nil)
 	if err != nil {
 		t.Fatal(err)
@@ -559,7 +624,7 @@ func TestEndToEndSync(t *testing.T) {
 				localFs:    test.fs,
 				bucket:     test.bucket,
 				mediaTypes: media.DefaultTypes,
-				cfg:        DeployConfig{MaxDeletes: -1},
+				cfg:        deployconfig.DeployConfig{MaxDeletes: -1},
 			}
 
 			// Initial deployment should sync remote with local.
@@ -642,7 +707,7 @@ func TestMaxDeletes(t *testing.T) {
 				localFs:    test.fs,
 				bucket:     test.bucket,
 				mediaTypes: media.DefaultTypes,
-				cfg:        DeployConfig{MaxDeletes: -1},
+				cfg:        deployconfig.DeployConfig{MaxDeletes: -1},
 			}
 
 			// Sync remote with local.
@@ -763,16 +828,16 @@ func TestIncludeExclude(t *testing.T) {
 			if err != nil {
 				t.Fatal(err)
 			}
-			tgt := &Target{
+			tgt := &deployconfig.Target{
 				Include: test.Include,
 				Exclude: test.Exclude,
 			}
-			if err := tgt.parseIncludeExclude(); err != nil {
+			if err := tgt.ParseIncludeExclude(); err != nil {
 				t.Error(err)
 			}
 			deployer := &Deployer{
 				localFs: fsTest.fs,
-				cfg:     DeployConfig{MaxDeletes: -1}, bucket: fsTest.bucket,
+				cfg:     deployconfig.DeployConfig{MaxDeletes: -1}, bucket: fsTest.bucket,
 				target:     tgt,
 				mediaTypes: media.DefaultTypes,
 			}
@@ -829,7 +894,7 @@ func TestIncludeExcludeRemoteDelete(t *testing.T) {
 			}
 			deployer := &Deployer{
 				localFs: fsTest.fs,
-				cfg:     DeployConfig{MaxDeletes: -1}, bucket: fsTest.bucket,
+				cfg:     deployconfig.DeployConfig{MaxDeletes: -1}, bucket: fsTest.bucket,
 				mediaTypes: media.DefaultTypes,
 			}
 
@@ -847,11 +912,11 @@ func TestIncludeExcludeRemoteDelete(t *testing.T) {
 			}
 
 			// Second sync
-			tgt := &Target{
+			tgt := &deployconfig.Target{
 				Include: test.Include,
 				Exclude: test.Exclude,
 			}
-			if err := tgt.parseIncludeExclude(); err != nil {
+			if err := tgt.ParseIncludeExclude(); err != nil {
 				t.Error(err)
 			}
 			deployer.target = tgt
@@ -881,7 +946,7 @@ func TestCompression(t *testing.T) {
 			deployer := &Deployer{
 				localFs:    test.fs,
 				bucket:     test.bucket,
-				cfg:        DeployConfig{MaxDeletes: -1, Matchers: []*Matcher{{Pattern: ".*", Gzip: true, re: regexp.MustCompile(".*")}}},
+				cfg:        deployconfig.DeployConfig{MaxDeletes: -1, Matchers: []*deployconfig.Matcher{{Pattern: ".*", Gzip: true, Re: regexp.MustCompile(".*")}}},
 				mediaTypes: media.DefaultTypes,
 			}
 
@@ -936,7 +1001,7 @@ func TestMatching(t *testing.T) {
 			deployer := &Deployer{
 				localFs:    test.fs,
 				bucket:     test.bucket,
-				cfg:        DeployConfig{MaxDeletes: -1, Matchers: []*Matcher{{Pattern: "^subdir/aaa$", Force: true, re: regexp.MustCompile("^subdir/aaa$")}}},
+				cfg:        deployconfig.DeployConfig{MaxDeletes: -1, Matchers: []*deployconfig.Matcher{{Pattern: "^subdir/aaa$", Force: true, Re: regexp.MustCompile("^subdir/aaa$")}}},
 				mediaTypes: media.DefaultTypes,
 			}
 
@@ -961,7 +1026,7 @@ func TestMatching(t *testing.T) {
 			}
 
 			// Repeat with a matcher that should now match 3 files.
-			deployer.cfg.Matchers = []*Matcher{{Pattern: "aaa", Force: true, re: regexp.MustCompile("aaa")}}
+			deployer.cfg.Matchers = []*deployconfig.Matcher{{Pattern: "aaa", Force: true, Re: regexp.MustCompile("aaa")}}
 			if err := deployer.Deploy(ctx); err != nil {
 				t.Errorf("no-op deploy with triple force matcher: %v", err)
 			}
