@@ -674,7 +674,7 @@ menu: main
 
 	b.AssertFileContent("public/en/index.html", `<a href="/en/p1/">p1</a><a href="/en/p2/">p2</a>`)
 	b.AssertFileContent("public/fr/index.html", `<a href="/fr/p1/">p1</a>`)
-	b.AssertLogNotContains("WARN")
+	b.AssertLogContains("! WARN")
 }
 
 func TestSectionPagesIssue12399(t *testing.T) {
