@@ -1,4 +1,4 @@
-// Copyright 2023 The Hugo Authors. All rights reserved.
+// Copyright 2024 The Hugo Authors. All rights reserved.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -59,3 +59,45 @@ func TestConfigLegacy(t *testing.T) {
 	conf := testconfig.GetTestConfigs(nil, v).Base.Minify
 	c.Assert(conf.MinifyOutput, qt.Equals, true)
 }
+
+func TestConfigNewCommentOptions(t *testing.T) {
+	c := qt.New(t)
+	v := config.New()
+
+	// setting the old options should automatically set the new options
+	v.Set("minify", map[string]any{
+		"tdewolff": map[string]any{
+			"html": map[string]any{
+				"keepConditionalComments": false,
+			},
+			"svg": map[string]any{
+				"decimal": "5",
+			},
+		},
+	})
+
+	conf := testconfig.GetTestConfigs(nil, v).Base.Minify
+
+	c.Assert(conf.Tdewolff.HTML.KeepSpecialComments, qt.Equals, false)
+	c.Assert(conf.Tdewolff.SVG.Precision, qt.Equals, 5)
+
+	// the new values should win, regardless of the contents of the old values
+	v = config.New()
+	v.Set("minify", map[string]any{
+		"tdewolff": map[string]any{
+			"html": map[string]any{
+				"keepConditionalComments": false,
+				"keepSpecialComments":     true,
+			},
+			"svg": map[string]any{
+				"decimal":   "5",
+				"precision": "10",
+			},
+		},
+	})
+
+	conf = testconfig.GetTestConfigs(nil, v).Base.Minify
+
+	c.Assert(conf.Tdewolff.HTML.KeepSpecialComments, qt.Equals, true)
+	c.Assert(conf.Tdewolff.SVG.Precision, qt.Equals, 10)
+}
