@@ -50,7 +50,7 @@ type LayoutDescriptor struct {
 }
 
 func (d LayoutDescriptor) isList() bool {
-	return !d.RenderingHook && d.Kind != "page" && d.Kind != "404"
+	return !d.RenderingHook && d.Kind != "page" && d.Kind != "404" && d.Kind != "sitemap" && d.Kind != "sitemapindex"
 }
 
 // LayoutHandler calculates the layout template to use to render a given output type.
@@ -222,7 +222,7 @@ func resolvePageTemplate(d LayoutDescriptor) []string {
 	}
 
 	switch d.Kind {
-	case "robotsTXT":
+	case "robotstxt":
 		layouts = append(layouts, "_internal/_default/robots.txt")
 	case "sitemap":
 		layouts = append(layouts, "_internal/_default/sitemap.xml")
