@@ -157,10 +157,11 @@ func TestDecodeCascadeConfig(t *testing.T) {
 }
 
 type testConfig struct {
-	environment string
-	running     bool
-	workingDir  string
-	multihost   bool
+	environment  string
+	running      bool
+	workingDir   string
+	multihost    bool
+	multilingual bool
 }
 
 func (c testConfig) Environment() string {
@@ -179,6 +180,10 @@ func (c testConfig) IsMultihost() bool {
 	return c.multihost
 }
 
+func (c testConfig) IsMultilingual() bool {
+	return c.multilingual
+}
+
 func TestIsGlobWithExtension(t *testing.T) {
 	c := qt.New(t)
 
